pub struct EncodedPostBundleFeedbackV1 {
pub header: EncodedPostBundleFeedbackHeaderV1,
pub feedbacks_bytes: Bytes,
}Fields
header: EncodedPostBundleFeedbackHeaderV1feedbacks_bytes: BytesImplementations
Sourceimpl EncodedPostBundleFeedbackV1
impl EncodedPostBundleFeedbackV1
pub fn to_bytes(&self) -> Result<Bytes>
pub fn from_bytes(bytes: Bytes) -> Result<Self>
Sourcepub fn verify(&self) -> Result<()>
pub fn verify(&self) -> Result<()>
Verifies that this bundle is legitimate enough to cache.
Checks:
- The bundle header is valid and its signature verifies.
- The feedback body is a valid multiple of
ENTRY_SIZE(no partial entries). - The header’s hash is the same as the body’s
- Each feedback entry’s proof-of-work is correct.
pub fn get_post_pow_for_feedback_type( &self, post_id: &Id, feedback_type: u8, ) -> Pow
Sourcepub fn merge(bundles: &[Self]) -> Option<Self>
pub fn merge(bundles: &[Self]) -> Option<Self>
Unions an array of bundles by taking the highest-pow entry for each
(post_id, feedback_type) pair across all bundles. The header is
taken from the most-recently-timestamped bundle. Returns None if
bundles is empty.
pub fn get_post_pows(&self, post_id: &Id) -> [Pow; 256]